@@ -85,11 +85,17 @@ def _patch_loop(loop):
                 handle._run()
         handle = None
 
+    def _check_running(self):
+        """Do not throw exception if loop is already running."""
+        pass
+
     cls = loop.__class__
     cls._run_once_orig = cls._run_once
     cls._run_once = _run_once
     cls._run_until_complete_orig = cls.run_until_complete
     cls.run_until_complete = run_until_complete
+    cls._check_running_orig = cls._check_running
+    cls._check_running = _check_running
     cls._nest_patched = True
 
 
